summaryrefslogtreecommitdiffstats
path: root/konversation/src/konviconfigdialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'konversation/src/konviconfigdialog.h')
-rw-r--r--konversation/src/konviconfigdialog.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/konversation/src/konviconfigdialog.h b/konversation/src/konviconfigdialog.h
index 6a7365c..9068eea 100644
--- a/konversation/src/konviconfigdialog.h
+++ b/konversation/src/konviconfigdialog.h
@@ -21,18 +21,18 @@
*/
/*
* KConfigDialog derivative allowing for a multi-level hierarchical TreeList.
* Differences from KConfigDialog:
* - Use TQStringList instead of TQString for the item name(s) in addPage and
* addPageInternal, thus calling the respective KDialogBase methods which
* allow specifying a path from which the TreeList hierarchy is constructed.
* - Use 16x16 icons in the TreeList.
* - Fill a new int m_lastAddedIndex with the pageIndex() of a new page added
* with addPageInternal, and offer a public interface int lastAddedIndex().
* See the KConfigDialog reference for detailed documentation.
*
* begin: Nov 22 2005
- * copyright: (C) 2005-2006 by Eike Hein, KConfigDialog developers
+ * copyright: (C) 2005-2006 by Eike Hein, TDEConfigDialog developers
* email: hein@kde.org
*/
@@ -44,9 +44,9 @@
#include <kdialogbase.h>
-class KConfig;
-class KConfigSkeleton;
-class KConfigDialogManager;
+class TDEConfig;
+class TDEConfigSkeleton;
+class TDEConfigDialogManager;
class KonviConfigDialog : public KDialogBase
{
@@ -64,7 +64,7 @@ class KonviConfigDialog : public KDialogBase
public:
KonviConfigDialog( TQWidget *parent, const char *name,
- KConfigSkeleton *config,
+ TDEConfigSkeleton *config,
DialogType dialogType = IconList,
int dialogButtons = Default|Ok|Apply|Cancel|Help,
ButtonCode defaultButton = Ok,
@@ -77,7 +77,7 @@ class KonviConfigDialog : public KDialogBase
const TQString &header=TQString(),
bool manage=true );
- void addPage( TQWidget *page, KConfigSkeleton *config,
+ void addPage( TQWidget *page, TDEConfigSkeleton *config,
const TQStringList &items,
const TQString &pixmapName,
const TQString &header=TQString() );
@@ -111,14 +111,14 @@ class KonviConfigDialog : public KDialogBase
void addPageInternal(TQWidget *page, const TQStringList &items,
const TQString &pixmapName, const TQString &header);
- void setupManagerConnections(KConfigDialogManager *manager);
+ void setupManagerConnections(TDEConfigDialogManager *manager);
private:
static TQAsciiDict<KonviConfigDialog> openDialogs;
- class KConfigDialogPrivate;
+ class TDEConfigDialogPrivate;
- KConfigDialogPrivate *d;
+ TDEConfigDialogPrivate *d;
int m_lastAddedIndex;
};
@@ -21,18 +21,18 @@
*/
/*
- * KConfigDialog derivative allowing for a multi-level hierarchical TreeList.
- * Differences from KConfigDialog:
+ * TDEConfigDialog derivative allowing for a multi-level hierarchical TreeList.
+ * Differences from TDEConfigDialog:
* - Use TQStringList instead of TQString for the item name(s) in addPage and
* addPageInternal, thus calling the respective KDialogBase methods which
@@ -21,18 +21,18 @@
* - Fill a new int m_lastAddedIndex with the pageIndex() of a new page added
* with addPageInternal, and offer a public interface int lastAddedIndex().
- * See the KConfigDialog reference for detailed documentation.
+ * See the TDEConfigDialog reference for detailed documentation.
*
* begin: Nov 22 2005